aboutsummaryrefslogtreecommitdiff
path: root/app
diff options
context:
space:
mode:
Diffstat (limited to 'app')
-rw-r--r--app/Exceptions/Handler.php22
1 files changed, 11 insertions, 11 deletions
diff --git a/app/Exceptions/Handler.php b/app/Exceptions/Handler.php
index 21c9784..e5bd8e2 100644
--- a/app/Exceptions/Handler.php
+++ b/app/Exceptions/Handler.php
@@ -2,14 +2,14 @@
namespace App\Exceptions;
-use Exception;
use Illuminate\Auth\AuthenticationException;
use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
+use Throwable;
class Handler extends ExceptionHandler
{
/**
* A list of the exception types that should not be reported.
*
* @var array
*/
@@ -23,28 +23,28 @@ class Handler extends ExceptionHandler
];
/**
* Report or log an exception.
*
- * This is a great spot to send exceptions to Sentry, Bugsnag, etc.
+ * This is a great spot to send throwables to Sentry, Bugsnag, etc.
*
- * @param \Exception $exception
+ * @param \Throwable $throwable
* @return void
*/
- public function report(Exception $exception)
+ public function report(Throwable $throwable)
{
- parent::report($exception);
+ parent::report($throwable);
}
/**
* Render an exception into an HTTP response.
*
* @param \Illuminate\Http\Request $request
- * @param \Exception $exception
+ * @param \Throwable $throwable
* @return \Illuminate\Http\Response
*/
- public function render($request, Exception $exception)
+ public function render($request, Throwable $throwable)
{
- return parent::render($request, $exception);
+ return parent::render($request, $throwable);
}
/**
@@ -2,14 +2,14 @@
{
/**
- * A list of the exception types that should not be reported.
+ * A list of the throwable types that should not be reported.
*
* @var array
@@ -23,28 +23,28 @@ class Handler extends ExceptionHandler
];
/**
- * Report or log an exception.
+ * Report or log a throwable.
*
@@ -23,28 +23,28 @@ class Handler extends ExceptionHandler
}
/**
- * Render an exception into an HTTP response.
+ * Render a throwable into an HTTP response.
*
* @param \Illuminate\Http\Request $request